package com.steerinfo.dil.controller;

import com.steerinfo.dil.model.Api;
import com.steerinfo.dil.model.ColumnData;
import com.steerinfo.dil.service.IColumnDataService;
import com.steerinfo.framework.controller.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @Author zhangnan
 * @Date 2021/6/17 8:31
 * @Version 1.0
 */
@RequestMapping("/${api.version}/columnData")
@io.swagger.annotations.Api(tags = "表头api接口")
@RestController
public class ColumnDataController extends BaseRESTfulController {
    @Autowired
    IColumnDataService columnDataService;

    @ApiOperation(value="根据apiId查询columnData")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "apiId", required = false, dataType = "Integer"),
    })
    @GetMapping
    public RESTfulResult getColumnData(Integer apiId){
        return success(columnDataService.getColumnData(apiId));
    }
    @ApiOperation(value="查询所有表格名称")
    @GetMapping("Tabs")
    private RESTfulResult getUserTabs(){
        return success(columnDataService.getUserTabs());
    }

    @ApiOperation(value="根据表格名查询字段")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "TableName", value = "表格名称", required = false, dataType = "String"),
    })
    @GetMapping("TabColumns/{TableName}")
    private RESTfulResult getUserTabColumns(@PathVariable("TableName") String TableName){
        return success(columnDataService.getUserTabColumns(TableName));
    }


    @ApiOperation(value="新增columnData")
    @PostMapping("insert/columnData")
    @Transactional
    public RESTfulResult insertColumnData(@RequestBody(required=false) Map<String,List<ColumnData>> columnDatas){
        BigDecimal apiId = columnDataService.getApiId();
        Api api = new Api();
        api.setApiId(apiId);
        columnDataService.insertApi(api);
        int ColumnDataId=1;
        List<ColumnData> columnDataMap = columnDatas.get("columnDatas");
        for (ColumnData columnData : columnDataMap) {
            columnData.setApiId(apiId);
            columnData.setDataId(columnDataService.getDataId());
            columnData.setColumnDataId(new BigDecimal(ColumnDataId));
            columnDataService.insertColumnData(columnData);
            ColumnDataId++;
        }
        return success(columnDataMap.get(0).getApiId());
    }

    @ApiOperation(value="修改columnData")
    @PostMapping("update/columnData")
    @Transactional
    public RESTfulResult updateColumnData(@RequestBody(required=false) Map<String,List<ColumnData>> Datas,
                                          BigDecimal apiId){
        List<ColumnData> columnDataMap =Datas.get("columnDatas");
        int ColumnDataId=1;
        //删除
        columnDataService.deleteByApiId(apiId);
        for (ColumnData columnData : columnDataMap) {
            columnData.setApiId(apiId);
            columnData.setDataId(columnDataService.getDataId());
            columnData.setColumnDataId(new BigDecimal(ColumnDataId));
            columnDataService.insertColumnData(columnData);
            ColumnDataId++;
        }
        return success();
    }
}
